#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_FFS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_FFS_HPP_INCLUDED

#include <boost/simd/bitwise/include/functions/ffs.hpp>

#endif
